@@ -452,14 +452,25 @@ class PyDMMainWindow(QMainWindow):
             self.resize(self._new_widget_size)
 
     def closeEvent(self, event):
-        self.clear_display_widget()
+        event.ignore()
+
+        def do_close():
+            self.clear_display_widget()
+            event.accept()
+
+        main_windows = [w for w in self.app.topLevelWidgets() if isinstance(w, QMainWindow)]
+        if len(main_windows) == 1 and main_windows[0] == self:
+            self._confirm_quit(callback=do_close)
+        else:
+            do_close()
 
     @Slot(bool)
     def quit_main_window(self, checked):
+        self._confirm_quit(callback=self.app.quit)
+
+    def _confirm_quit(self, callback):
         quit_message = QMessageBox.question(
             self, 'Quitting Application', 'Exit Application?',
             QMessageBox.Yes | QMessageBox.No)
         if quit_message == QMessageBox.Yes:
-            self.app.quit()
-        else:
-            pass
+            callback()
