@@ -1,6 +1,5 @@
 import sys
 import argparse
-import json
 import logging
 
 
@@ -13,6 +12,10 @@ def main():
     logger.setLevel("INFO")
     handler.setLevel("INFO")
 
+    from pydm.utilities import setup_renderer
+
+    setup_renderer()
+
     try:
         """
         We must import QtWebEngineWidgets before creating a QApplication
